@@ -27,7 +27,7 @@ Text::BibTeX::Bib - defines the "Bib" database structure
 
 =head1 SYNOPSIS
 
-   $bibfile = Text::BibTeX::File $filename->new;
+   $bibfile = new Text::BibTeX::File $filename;
    $bibfile->set_structure ('Bib',
                             # Default option values:
                             sortby => 'name',
@@ -45,11 +45,11 @@ Text::BibTeX::Bib - defines the "Bib" database structure
    $bibfile->set_option (labels => 'alpha');   # not implemented yet!
 
    # parse entry from $bibfile and automatically make it a BibEntry
-   $entry = Text::BibTeX::Entry->new($bibfile);
+   $entry = new Text::BibTeX::Entry $bibfile;
 
    # or get an entry from somewhere else which is hard-coded to be
    # a BibEntry
-   $entry = Text::BibTeX::BibEntry->new(...);
+   $entry = new Text::BibTeX::BibEntry ...;
 
    $sortkey = $entry->sort_key;
    @blocks = $entry->format;
@@ -109,9 +109,8 @@ BibTeX 0.99-style bibliography databases.)
 
 package Text::BibTeX::BibStructure;
 use strict;
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA);
 @ISA = qw(Text::BibTeX::Structure);
-$VERSION = '0.76_02';
 
 =head1 STRUCTURE OPTIONS
 
@@ -448,15 +447,33 @@ L<Text::BibTeX::BibFormat> for details on these two methods.
 
 package Text::BibTeX::BibEntry;
 use strict;
-use vars qw(@ISA $VERSION);
-
-$VERSION = '0.76_02';
+use vars qw(@ISA);
 
 use Text::BibTeX::BibSort;
 use Text::BibTeX::BibFormat;
 
 @ISA = qw(Text::BibTeX::BibSort Text::BibTeX::BibFormat);
- 
+
+# Pre-define the "month name" macros for compatibility with BibTeX.
+# This ignores all sorts of issues, like internationalization and
+# abbreviation.  
+my %month_names = 
+   ('jan' => 'January',
+    'feb' => 'February',
+    'mar' => 'March',
+    'apr' => 'April',
+    'may' => 'May',
+    'jun' => 'June',
+    'jul' => 'July',
+    'aug' => 'August',
+    'sep' => 'September',
+    'oct' => 'October',
+    'nov' => 'November',
+    'dec' => 'December');
+
+my ($macro, $expansion);
+Text::BibTeX::add_macro_text ($macro, $expansion)
+   while (($macro, $expansion) = each %month_names);    
 
 1;
 
